```
Usage: vcd vapp network services dhcp enable-dhcp [OPTIONS] <vapp-name>
                                                  <network-name>

Options:
  --enable / --disable
  -h, --help            Show this message and exit.

```
